@@ -9,6 +9,6 @@ routes = [
     # schema json输出地址
     Route(path='/schema.json', endpoint=openapi_schema, include_in_schema=False),
     # 静态资源包代理地址
-    Mount(path='/swagger/static', app=StaticFiles(directory='statics', packages=['restful_starlette.apps.swagger', ]),
+    Mount(path='/swagger/static', app=StaticFiles(directory='statics', packages=['restful_starlette.apps.swagger', ], check_dir=False),
           name="swagger"),
 ]
